@@ -1,5 +1,5 @@
 from .date_calculations import chronological_decimal_age, corrected_decimal_age, chronological_calendar_age, estimated_date_delivery, corrected_gestational_age
-from .global_functions import centile, sds_for_measurement, measurement_from_sds, percentage_median_bmi, mid_parental_height, generate_centile
+from .global_functions import centile, sds_for_measurement, measurement_from_sds, percentage_median_bmi, mid_parental_height
 from .centile_bands import centile_band_for_centile
 from .bmi_functions import bmi_from_height_weight, weight_for_bmi_height
 from .age_advice_strings import comment_prematurity_correction
@@ -9,5 +9,5 @@ from .uk_who import select_reference_data_for_uk_who_chart
 from .turner import select_reference_data_for_turner
 from .trisomy_21 import select_reference_data_for_trisomy_21
 from .measurement import Measurement
-from .chart_functions import create_chart, create_plottable_child_data
+from .chart_functions import create_chart, create_plottable_child_data, generate_custom_centile
 from .constants import *
